from flask_wtf import FlaskForm
from wtforms import StringField, SubmitField, PasswordField, IntegerField, HiddenField,SelectField
from wtforms.validators import Length, EqualTo, Email, InputRequired, Regexp, NumberRange,DataRequired

# register form


class RegisterForm(FlaskForm):
    username = StringField(u'First name',
                           validators=[InputRequired(message=u'Please input your first name.'), Length(1, 20), Regexp(r'[a-zA-Z0-9]+', message=u"Your first name contains invalid characters.")])
    email = StringField(u'Email', validators=[
        InputRequired(message=u'Please input your email.'), Length(1, 20),
        Email(message=u'Invalid email. Please check.')])
    password = PasswordField(u'Password',
                             validators=[InputRequired(message=u'Please input your password.'), Length(1, 20), Regexp(r'[a-zA-Z0-9]+', message=u"Your password contains invalid characters.")])
    password2 = PasswordField(u'Confirm Password',
                              validators=[InputRequired(message=u'Please repeat your password.'), EqualTo("password", message=u"Passwords do not match. Please try again."), ])
    submit = SubmitField(u'Register')

# login form


class LoginForm(FlaskForm):
    # username = StringField(u'username',
    #                        validators=[DataRequired(message=u'please input your username')])
    email = StringField(u'Email', validators=[
        DataRequired(message=u'Please input your email.'), Length(1, 20),
        Email(message=u'Invalid email. Please check.')])
    password = PasswordField(u'Password',
                             validators=[DataRequired(message=u'Please input your password.'), Length(1, 20)])
    submit = SubmitField(u'Login')

# post form


class PostForm(FlaskForm):
    title = StringField(u'Title',
                        validators=[DataRequired(message=u'Please input your title.')])
    description = StringField(u'Description', validators=[
        DataRequired(message=u'Please input your description.')])
    content = StringField(u'Content',
                          validators=[DataRequired(message=u'Please input your content.')])
    submit = SubmitField(u'Post')

# post form


class CommentForm(FlaskForm):
    content = StringField(u'Content',
                          validators=[DataRequired(message=u'Please input your content.')])
    score = IntegerField(u'Stars', validators=[NumberRange(min=1, max=5)])
    post_id = HiddenField('post_id')
    submit = SubmitField(u'comment')
    
    
class PostOrderForm(FlaskForm):
     post_order = SelectField('Order', choices=[
        ('asc', 'Sort  posts ascending'),
        ('desc', 'Sort posts  descending'),
    ])
     submit = SubmitField('Sort')
