from datetime import datetime
from blog import db, app
from werkzeug.security import check_password_hash, generate_password_hash


class Post(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    date = db.Column(db.DateTime, nullable=False, default=datetime.utcnow)
    title = db.Column(db.Text, nullable=False)
    content = db.Column(db.Text, nullable=False)
    description = db.Column(db.Text, nullable=False)
    image_file = db.Column(db.String(250), nullable=True,
                           default='default.jpg')

    author_id = db.Column(db.Integer, db.ForeignKey("user.id"), nullable=False)
    comment = db.relationship("Comment", backref="post", lazy=True)

    def __repr__(self):
        return f"Post('{self.date}', '{self.title}', '{self.content}')"


class User(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    username = db.Column(db.String(15), unique=True, nullable=False)
    email = db.Column(db.String(120), unique=True, nullable=False)
    post = db.relationship("Post", backref="user", lazy=True)
    password = db.Column(db.String(120), nullable=False)

    def __init__(self, username, email, password):
        self.email = email
        self.username = username
        self.password_hash = password

    def __repr__(self):
        return f"User('{self.username}', '{self.email}')"

    def verify_password(self, password):
        app.logger.info(f"check password for {password}")
        return check_password_hash(self.password, password)

    @property
    def password_hash(self):
        raise AttributeError('Password is not readable.')

    @password_hash.setter
    def password_hash(self, password):
        self.password = generate_password_hash(password)


class Comment(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    date = db.Column(db.DateTime, nullable=False, default=datetime.utcnow)
    content = db.Column(db.Text, nullable=False)
    username = db.Column(db.String(200), nullable=False)
    score = db.Column(db.Integer, nullable=True)
    author_id = db.Column(db.Integer, db.ForeignKey("user.id"), nullable=False)
    blog_id = db.Column(db.Integer, db.ForeignKey("post.id"), nullable=False)

    def __repr__(self):
        return f"Comment('{self.date}','{self.content}')"
